==> open-cluster-management-discovery-model-6.2.0-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveredClusterFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiscoveredClusterFluentImpl<A extends DiscoveredClusterFluent<A>> extends BaseFluent<A> implements DiscoveredClusterFluent<A>{
  public DiscoveredClusterFluentImpl() {
  }
  public DiscoveredClusterFluentImpl(DiscoveredCluster instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DiscoveredClusterSpecBuilder spec;
  private DiscoveredClusterStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DiscoveredClusterFluent.MetadataNested<A> withNewMetadata() {
    return new DiscoveredClusterFluentImpl.MetadataNestedImpl();
  }
  public DiscoveredClusterFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DiscoveredClusterFluentImpl.MetadataNestedImpl(item);
  }
  public DiscoveredClusterFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DiscoveredClusterFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DiscoveredClusterFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveredClusterSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DiscoveredClusterSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DiscoveredClusterSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DiscoveredClusterSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DiscoveredClusterFluent.SpecNested<A> withNewSpec() {
    return new DiscoveredClusterFluentImpl.SpecNestedImpl();
  }
  public DiscoveredClusterFluent.SpecNested<A> withNewSpecLike(DiscoveredClusterSpec item) {
    return new DiscoveredClusterFluentImpl.SpecNestedImpl(item);
  }
  public DiscoveredClusterFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DiscoveredClusterFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DiscoveredClusterSpecBuilder().build());
  }
  public DiscoveredClusterFluent.SpecNested<A> editOrNewSpecLike(DiscoveredClusterSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveredClusterStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DiscoveredClusterStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DiscoveredClusterStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DiscoveredClusterStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DiscoveredClusterFluent.StatusNested<A> withNewStatus() {
    return new DiscoveredClusterFluentImpl.StatusNestedImpl();
  }
  public DiscoveredClusterFluent.StatusNested<A> withNewStatusLike(DiscoveredClusterStatus item) {
    return new DiscoveredClusterFluentImpl.StatusNestedImpl(item);
  }
  public DiscoveredClusterFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DiscoveredClusterFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DiscoveredClusterStatusBuilder().build());
  }
  public DiscoveredClusterFluent.StatusNested<A> editOrNewStatusLike(DiscoveredClusterStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DiscoveredClusterFluentImpl that = (DiscoveredClusterFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DiscoveredClusterFluent.MetadataNested<N>> implements DiscoveredClusterFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DiscoveredClusterFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DiscoveredClusterSpecFluentImpl<DiscoveredClusterFluent.SpecNested<N>> implements DiscoveredClusterFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DiscoveredClusterSpec item) {
      this.builder = new DiscoveredClusterSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DiscoveredClusterSpecBuilder(this);
    }
    DiscoveredClusterSpecBuilder builder;
    public N and() {
      return (N) DiscoveredClusterFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DiscoveredClusterStatusFluentImpl<DiscoveredClusterFluent.StatusNested<N>> implements DiscoveredClusterFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DiscoveredClusterStatus item) {
      this.builder = new DiscoveredClusterStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DiscoveredClusterStatusBuilder(this);
    }
    DiscoveredClusterStatusBuilder builder;
    public N and() {
      return (N) DiscoveredClusterFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-discovery-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveredClusterFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiscoveredClusterFluentImpl<A extends DiscoveredClusterFluent<A>> extends BaseFluent<A> implements DiscoveredClusterFluent<A>{
  public DiscoveredClusterFluentImpl() {
  }
  public DiscoveredClusterFluentImpl(DiscoveredCluster instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DiscoveredClusterSpecBuilder spec;
  private DiscoveredClusterStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DiscoveredClusterFluentImpl.MetadataNested<A> withNewMetadata() {
    return new DiscoveredClusterFluentImpl.MetadataNestedImpl();
  }
  public DiscoveredClusterFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DiscoveredClusterFluentImpl.MetadataNestedImpl(item);
  }
  public DiscoveredClusterFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DiscoveredClusterFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DiscoveredClusterFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveredClusterSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DiscoveredClusterSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DiscoveredClusterSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DiscoveredClusterSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DiscoveredClusterFluentImpl.SpecNested<A> withNewSpec() {
    return new DiscoveredClusterFluentImpl.SpecNestedImpl();
  }
  public DiscoveredClusterFluentImpl.SpecNested<A> withNewSpecLike(DiscoveredClusterSpec item) {
    return new DiscoveredClusterFluentImpl.SpecNestedImpl(item);
  }
  public DiscoveredClusterFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DiscoveredClusterFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DiscoveredClusterSpecBuilder().build());
  }
  public DiscoveredClusterFluentImpl.SpecNested<A> editOrNewSpecLike(DiscoveredClusterSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveredClusterStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DiscoveredClusterStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DiscoveredClusterStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DiscoveredClusterStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DiscoveredClusterFluentImpl.StatusNested<A> withNewStatus() {
    return new DiscoveredClusterFluentImpl.StatusNestedImpl();
  }
  public DiscoveredClusterFluentImpl.StatusNested<A> withNewStatusLike(DiscoveredClusterStatus item) {
    return new DiscoveredClusterFluentImpl.StatusNestedImpl(item);
  }
  public DiscoveredClusterFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DiscoveredClusterFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DiscoveredClusterStatusBuilder().build());
  }
  public DiscoveredClusterFluentImpl.StatusNested<A> editOrNewStatusLike(DiscoveredClusterStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiscoveredClusterFluentImpl that = (DiscoveredClusterFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DiscoveredClusterFluentImpl.MetadataNested<N>> implements DiscoveredClusterFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DiscoveredClusterFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DiscoveredClusterSpecFluentImpl<DiscoveredClusterFluentImpl.SpecNested<N>> implements DiscoveredClusterFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DiscoveredClusterSpec item) {
      this.builder = new DiscoveredClusterSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DiscoveredClusterSpecBuilder(this);
    }
    DiscoveredClusterSpecBuilder builder;
    public N and() {
      return (N) DiscoveredClusterFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DiscoveredClusterStatusFluentImpl<DiscoveredClusterFluentImpl.StatusNested<N>> implements DiscoveredClusterFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DiscoveredClusterStatus item) {
      this.builder = new DiscoveredClusterStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DiscoveredClusterStatusBuilder(this);
    }
    DiscoveredClusterStatusBuilder builder;
    public N and() {
      return (N) DiscoveredClusterFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
